┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/kitemviews/kstandarditemmodel.h
diff options
context:
space:
mode:
authorPeter Penz <[email protected]>2012-05-13 23:29:28 +0200
committerPeter Penz <[email protected]>2012-05-13 23:30:38 +0200
commit6e9713c558ad07b0baa2a79ae69328fda7b61a15 (patch)
tree0ada814c2ca39dc9e88ea2294d7a1c8d8c567cdc /src/kitemviews/kstandarditemmodel.h
parent1426b8d3c785e47fab6312e9d01a21dc265aadb8 (diff)
PlacesItemModel: Remove setItemHidden and isItemHidden
This should be handled automatically when the hidden-state of the item itself gets toggled.
Diffstat (limited to 'src/kitemviews/kstandarditemmodel.h')
-rw-r--r--src/kitemviews/kstandarditemmodel.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/kitemviews/kstandarditemmodel.h b/src/kitemviews/kstandarditemmodel.h
index 510342a81..be5b7c438 100644
--- a/src/kitemviews/kstandarditemmodel.h
+++ b/src/kitemviews/kstandarditemmodel.h
@@ -52,11 +52,11 @@ public:
void insertItem(int index, KStandardItem* item);
/**
- * Replaces the item on the index \a index by \a item.
+ * Changes the item on the index \a index to \a item.
* KStandardItemModel takes the ownership of the item. The
* old item gets deleted.
*/
- void replaceItem(int index, KStandardItem* item);
+ void changeItem(int index, KStandardItem* item);
void removeItem(int index);
KStandardItem* item(int index) const;
@@ -84,10 +84,10 @@ protected:
virtual void onItemInserted(int index);
/**
* Is invoked after an item has been replaced and before the signal
* itemsChanged() gets emitted.
*/
- virtual void onItemReplaced(int index);
+ virtual void onItemChanged(int index, const QSet<QByteArray>& changedRoles);
/**
* Is invoked after an item has been removed and before the signal
@@ -84,10 +84,10 @@ protected:
virtual void onItemInserted(int index);
/**
- * Is invoked after an item has been replaced and before the signal
- * itemsChanged() gets emitted.
+ * Is invoked after an item or one of its roles has been changed and
+ * before the signal itemsChanged() gets emitted.
*/